<?php

declare(strict_types=1);

namespace Drupal\aws;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Entity\EntityTypeManagerInterface;

use function Aws\manifest;

/**
 * AWS service class.
 */
class Aws implements AwsInterface {

  /**
   * Constructs an Aws object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $configFactory
   *   The config factory.
   * @param \Drupal\Core\Entity\EntityTypeManagerInterface $entityTypeManager
   *   The entity type manager.
   */
  public function __construct(
    protected ConfigFactoryInterface $configFactory,
    protected EntityTypeManagerInterface $entityTypeManager,
  ) {}

  /**
   * {@inheritdoc}
   */
  public function getProfiles() {
    $storage = $this->entityTypeManager->getStorage('aws_profile');
    /** @var \Drupal\aws\Entity\ProfileInterface[] $profiles */
    $profiles = $storage->loadMultiple();

    return $profiles;
  }

  /**
   * {@inheritdoc}
   */
  public function getProfile(string $service_id) {
    $settings = $this->getServiceConfig($service_id);

    if (!$settings || $settings['profile'] == 'default') {
      return $this->getDefaultProfile();
    }

    $storage = $this->entityTypeManager->getStorage('aws_profile');
    /** @var \Drupal\aws\Entity\ProfileInterface $profile */
    $profile = $storage->load($settings['profile']);

    return $profile;
  }

  /**
   * {@inheritdoc}
   */
  public function getDefaultProfile() {
    $storage = $this->entityTypeManager->getStorage('aws_profile');
    /** @var \Drupal\aws\Entity\ProfileInterface[] $profiles */
    $profiles = $storage->loadByProperties(['default' => TRUE]);

    return reset($profiles);
  }

  /**
   * {@inheritdoc}
   */
  public function getServices() {
    return manifest();
  }

  /**
   * {@inheritdoc}
   */
  public function getService(string $service_id) {
    return manifest($service_id);
  }

  /**
   * {@inheritdoc}
   */
  public function getServiceConfig(string $service_id) {
    if (!$service_id) {
      return [];
    }

    $config = $this->configFactory->get('aws.settings');
    $services = $config->get('services');

    return $services[$service_id] ?? [];
  }

  /**
   * {@inheritdoc}
   */
  public function setServiceConfig(string $service_id, ?array $settings) {
    $config = $this->configFactory->getEditable('aws.settings');
    $services = $config->get('services');

    if ($settings === NULL) {
      unset($services[$service_id]);
    }
    else {
      $services[$service_id] = $settings;
    }

    $config->set('services', $services);
    $config->save();
  }

  /**
   * {@inheritdoc}
   */
  public function getOverrides() {
    $config = $this->configFactory->get('aws.settings');
    $services = $config->get('services') ?? [];

    return $services;
  }

}
