<?php

namespace Drupal\aws\Entity;

use Drupal\Core\Config\Entity\ConfigEntityInterface;

/**
 * Provides an interface defining an AWS Profile entity.
 */
interface ProfileInterface extends ConfigEntityInterface {

  /**
   * Environment variable credential provider.
   */
  const PROVIDER_ENV = 'env';

  /**
   * Credentials file credential provider.
   */
  const PROVIDER_FILE = 'file';

  /**
   * Access keys credential provider.
   */
  const PROVIDER_KEYS = 'key';

  /**
   * Get the credential provider of the profile.
   *
   * @return string
   *   The access key of the profile.
   */
  public function getProvider();

  /**
   * Set the credential provider for the profile.
   *
   * @return $this
   */
  public function setProvider(string $provider);

  /**
   * Get the credential provider configuration.
   *
   * @return array
   *   The credential provider configuration.
   */
  public function getProviderConfig();

  /**
   * Set the credential provider configuration.
   *
   * @return $this
   */
  public function setProviderConfig(array $config);

  /**
   * Get the region of the profile.
   *
   * @return string
   *   The region of the profile.
   */
  public function getRegion();

  /**
   * Set the region of the profile.
   *
   * @return $this
   */
  public function setRegion(string $region);

  /**
   * Get the encryption profile for the profile.
   *
   * @return string
   *   The encryption profile of the profile.
   */
  public function getEncryptionProfile();

  /**
   * Set the encryption profile for the profile.
   *
   * @return $this
   */
  public function setEncryptionProfile(string $encryption_profile);

  /**
   * Whether the profile is the default or not.
   *
   * @return bool
   *   TRUE if the profile is the default.
   */
  public function isDefault();

  /**
   * Set the profile as the default.
   *
   * @return $this
   */
  public function setDefault(bool $default);

  /**
   * Returns the arguments required to instantiate an AWS service client.
   *
   * @param string $version
   *   The API version to use. Defaults to "latest".
   *
   * @return array
   *   The client arguments.
   */
  public function getClientArgs(string $version = 'latest');

}
