<?php

namespace Drupal\Tests\aws\Kernel;

/**
 * Tests the AWS Profile entity encryption functionality.
 *
 * @group aws
 */
class EncryptionTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'aws',
    'aws_test',
    'aws_encrypted_test',
    'encrypt',
    'real_aes',
    'key',
  ];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $this->installConfig('aws_encrypted_test');

    $storage = $this->entityTypeManager->getStorage('aws_profile');
    $this->profile = $storage->load('aws_encrypted');
  }

  /**
   * Tests getting an encrypted secret access key.
   *
   * @covers ::getCredentials
   */
  public function testGetSecretAccessKey() {
    $config = $this->profile->getProviderConfig();
    $this->assertEquals('TestSecretKey', $config['secret']);
  }

  /**
   * Tests setting an encrypted secret access key.
   *
   * @covers ::setCredentials
   */
  public function testSetSecretAccessKey() {
    $new_config = [
      'key_id' => $this->randomString(),
      'secret' => $this->randomString(),
    ];

    $this->profile->setProviderConfig($new_config);
    $config = $this->profile->getProviderConfig();

    $this->assertEquals($new_config['secret'], $config['secret']);
  }

}
