<?php

namespace Drupal\Tests\aws\Kernel;

use Drupal\aws\Entity\ProfileInterface;

/**
 * Tests the AWS Profile entity.
 *
 * @group aws
 */
class ProfileTest extends KernelTestBase {

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();

    $storage = $this->entityTypeManager->getStorage('aws_profile');
    $this->profile = $storage->load('aws_test');
  }

  /**
   * Tests getting the credential provider.
   *
   * @covers ::getProvider
   */
  public function testGetProvider() {
    $this->assertEquals(ProfileInterface::PROVIDER_KEYS, $this->profile->getProvider());
  }

  /**
   * Tests setting the credential provider.
   *
   * @covers ::setProvider
   */
  public function testSetProvider() {
    $this->profile->setProvider(ProfileInterface::PROVIDER_ENV);
    $this->assertEquals(ProfileInterface::PROVIDER_ENV, $this->profile->getProvider());
  }

  /**
   * Tests getting the provider configuration.
   *
   * @covers ::getProviderConfig
   */
  public function testGetProviderConfig() {
    $config = $this->profile->getProviderConfig();

    $this->assertEquals('TestAccessKey', $config['key_id']);
    $this->assertEquals('TestSecretKey', $config['secret']);
  }

  /**
   * Tests setting the provider configuration.
   *
   * @covers ::setProviderConfig
   */
  public function testSetProviderConfig() {
    $new_config = [
      'key_id' => $this->randomString(),
      'secret' => $this->randomString(),
    ];

    $this->profile->setProviderConfig($new_config);
    $config = $this->profile->getProviderConfig();

    $this->assertEquals($new_config['key_id'], $config['key_id']);
    $this->assertEquals($new_config['secret'], $config['secret']);
  }

  /**
   * Tests checking if a profile is the default.
   *
   * @covers ::isDefault
   */
  public function testIsDefault() {
    $this->assertTrue($this->profile->isDefault());
  }

  /**
   * Tests setting the default status of a profile.
   *
   * @covers ::setDefault
   */
  public function testSetDefault() {
    $this->profile->setDefault(FALSE);
    $this->assertFalse($this->profile->isDefault());
  }

}
